/* Part to maintain the images. */

#include <gl/gl.h>
#include <gl/image.h>
#include "idisp.h"

/******* Display image defines . . ***********/

#ifndef DISPIMGDEF
#define DISPIMGDEF

typedef struct dispimage {
    struct dispimage *next;
    int 		type;
    int 		xsize;
    int 		ysize;
    unsigned char 	*data;
} DISPIMAGE;

#define DI_WRITEPIXELS 		0
#define DI_WRITERGB 		1
#define DI_RECTWRITE 		2
#define DI_LRECTWRITE		3

DISPIMAGE *makedisprgn();
DISPIMAGE *makedisp();
DISPIMAGE *readdispimage();

#endif DISPIMGDEF

/*********************** file names **********************/

static int fnumb = 0;

static char fname[256], prevname[256];;

char *current_file_name()
/* returns a pointer to the current file name */
{
  if (fnumb>0) return fname; else return NULL;
}

char *previous_file_name()
/* returns name of previous file. */
{
  if (fnumb<=1) return NULL;
  sprintf(prevname,"/usr/tmp/tmpimg%i.rgb",fnumb-1);
  return prevname;
}

char *new_file_name()
/* Creates a new file name. */
{
  sprintf(fname,"/usr/tmp/tmpimg%i.rgb",++fnumb);
  return current_file_name();
}

char *last_file_name()
/* Goes back to the previous file name */
{
  if (fnumb>1) 
    sprintf(fname,"/usr/tmp/tmpimg%i.rgb",--fnumb);
  return current_file_name();
}

/**************** Redrawing etc. *********************/

IMAGE *current_im = NULL;
DISPIMAGE *current_dim;

static long wind = -1;
static int initialized = 0;

void set_image_file()
/* Sets the current image file to the current file. */
{
  long x,y;
  if (current_file_name() == NULL) return;
  current_im = iopen(current_file_name(),"r");
  if (current_im == NULL) return;
  current_dim = makedisp(current_im);
  iclose(current_im);
  if (!initialized)
  {
    initialized = 1;
    prefsize(current_im->xsize,current_im->ysize);
    wind = winopen("Image");
  }
  else
  {
    winset(wind);
    getorigin(&x,&y);
    winposition(x,x+current_im->xsize-1,y,y+current_im->ysize-1);
  }
  redraw_image();
}

void redraw_image()
/* Redraws the image. */
{
  winset(wind);
  reshapeviewport();
  setimagemode(current_im);
  drawimage(current_dim,0,0);
}

void get_image_size(int *w, int *h)
{
  *w = -1; *h = -1;
  if (current_im == NULL) return;
  *w = current_im->xsize;
  *h = current_im->ysize;
}

